%% ------------------------------------------------------------------------
% The file is part of the numerical models: "Numerical models for the
% design and analysis of heat pumps with zeotropic mixtures". All
% information about copyright, licenses and authors can be found in the
% attached documentation.
% doi: 10.11583/DTU.6825443
% Copyright (c) 2018, B. Zhlsdorf, DTU <bezuhls@mek.dtu.dk>, 03/12/2018
% -------------------------------------------------------------------------

% --------------------------------------------------------------------- %%
%                          Load Inputs                                   %
% ---------------------------------------------------------------------  %   
% load('CaseStudy_I/20180627/Results_complete.mat');
load('CaseStudy_I/Inputs_CaseStudy_I.mat');

% Load list of fluids
ListOfFluids;

% Define best cases:
best_solutions = [
                  20 11   1 2   % Ammonia
                   9 10   1 2   % Butane
                  16 11   1 2   % R1234zeZ
                   4  7 0.2 2   % 20%CO2 / 80 % DME
                   5 17 0.3 2   % 30% Propylene / 70% R1234zeZ
                   5  9 0.5 2   % 50% Propylene / 50% Butane
                   6 10 0.8 2   % 80% Propena / 20% IsoPentane
                   7 10 0.5 2   % 50% DME / 50% IsoPentane
                                  ];
% Long version
% best_solutions = [
%                    5 10   1 2   % Propylene
%                    6 11   1 2   % Propane
%                    7 10   1 2   % DME
%                    8 11   1 2   % IsoButane
%                    9 10   1 2   % Butane
%                   10 11   1 2   % IsoPentane
%                   11 17   1 2   % DEE
%                   12 11   1 2   % Pentane
%                   13 11   1 2   % Hexane
%                   14 11   1 2   % Heptane
%                   15 11   1 2   % R1234yf
%                   16 11   1 2   % R1234ZEE
%                   17 11   1 2   % R1234ZEZ
%                   18 11   1 2   % R1234ZDE
%                   19 11   1 2   % R134a
%                   20 11   1 2   % Ammonia
%                    4  7 0.2 2   % 20%CO2 / 80 % DME
%                    5 17 0.3 2   % 30% Propylene / 70% R1234zeZ
%                    5  9 0.5 2   % 50% Propylene / 50% Butane
%                    6 10 0.8 2   % 80% Propena / 20% IsoPentane
%                    7 10 0.5 2   % 50% DME / 50% IsoPentane
%                    7 11 0.6 2   % 60% DME / 40% DEE
%                   11 16 0.4 2   % 40%DEE / 60% R1234zEE
%                   13 17 0.4 2   % 40% Hexane / 60% R1234zeZ
%                                 ];
 
% Pure Fluids
% best_solutions = [
%                    5 10   1 2   % Propylene
%                    6 11   1 2   % Propane
%                    7 10   1 2   % DME
%                    8 11   1 2   % IsoButane
%                    9 10   1 2   % Butane
%                   10 11   1 2   % IsoPentane
%                   11 17   1 2   % DEE
%                   12 11   1 2   % Pentane
%                   13 11   1 2   % Hexane
%                   14 11   1 2   % Heptane
%                   15 11   1 2   % R1234yf
%                   16 11   1 2   % R1234ZEE
%                   17 11   1 2   % R1234ZEZ
%                   18 11   1 2   % R1234ZDE
%                   19 11   1 2   % R134a
%                   20 11   1 2   % Ammonia
%                                 ];
                                          
n_results = length(best_solutions(:,1));                     
                     
summary_cell = cell(n_results, 8);   
% --------------------------------------------------------------------- %%
%                    Define  Cycle Parameter                             %
% ---------------------------------------------------------------------  %   

% Set Pressure drops for refrigerant flow in flow direction
    % Evaporator
    cycleInput.dp_evap  = 0*ones(componentInput.HX.n_states_evap-1,1);%  zeros(componentInput.HX.n_states_evap-1,1);
    % Superheater
    cycleInput.dp_sh    = 0*ones(componentInput.HX.n_states_sh-1,1);
    
    % Desuperheater
    cycleInput.dp_desup = 0*ones(componentInput.HX.n_states_desup-1,1);
    % Condenser
    cycleInput.dp_cond  = 0*ones(componentInput.HX.n_states_cond-1,1);   
    % Subcooler
    cycleInput.dp_sub   = 0*ones(componentInput.HX.n_states_sub-1,1);      

% Compressor
    % Constant isentropic compressor efficiency
    cycleInput.Define_Efficiency = 'constant';    % -> componentInput.Comp.eta_is_comp_design is used
    
% --------------------------------------------------------------------- %%
%                  Define  Boundary Conditions                           %
% ---------------------------------------------------------------------  %   
% Heat Exchanger
    cycleInput.DefineHX     = 'Pinch';       % Design approach to set the exact pinch point temperatures in all heat exchangers (Note: E.g. NPV optimization might yield a higher pinch temperature diff.)
    componentInput.HX.delta_T_pinch_source_min = 3;   % [K]
    componentInput.HX.delta_T_pinch_sink_min = 3;     % [K]
    componentInput.HX.delta_T_pinch_sub_min = 3;      % [K]      
    
    
% Optimized Variable
   cycleInput.Objective    = 'COP';            % Optimization yields the highest obtainable coefficient of performance (COP) 

                                                
% --------------------------------------------------------------------- %%
%                        Calculation Options                             %
% ---------------------------------------------------------------------  %      
    economyInput.calcInv    = 'on';     % Define if investment cost should be calculated -> can be replaced by 'off'
    economyInput.calcEco    = 'on';     % Define if economy should be calculated -> can be replaced by 'off'
        
    cycleInput.calcExergy   = 'on';     % Define if exergy analysis is conducted -> can be replaced by 'off'

% --------------------------------------------------------------------- %%
%                           Start Screening                              %
% ---------------------------------------------------------------------  %   

for iter_results=1:n_results
    % Superheating
    delta_T_minSH_vector = [0.05 5];
    cycleInput.delta_T_minSH = delta_T_minSH_vector(best_solutions(iter_results, 4));
    
    % Define Medium
    % Define composition between 0 ... 1
    x_1 = best_solutions(iter_results, 3);
    x_2=1-x_1;
    
    medium_ID1 = best_solutions(iter_results, 1);
    medium_ID2 = best_solutions(iter_results, 2);
    
    % Definition of medium string
    if x_1==1
        medium = {medium_vector{medium_ID1}};
        composition = 1;
    elseif x_1==0
        medium = {medium_vector{medium_ID2}};
        composition = 1;
    else
        medium = {medium_vector{medium_ID1}, medium_vector{medium_ID2}};
        composition = [x_1; x_2];
    end
    
    cycleInput.medium = medium;
    cycleInput.composition = composition;
    
    if x_1==1
        cycleInput.mediumString = strcat(medium_vector_full(medium_ID1));
        simpleMediumString = strcat(medium_vector_full{medium_ID1});
    elseif x_1==0
        cycleInput.mediumString = strcat(medium_vector_full(medium_ID2));
        simpleMediumString = strcat(medium_vector_full{medium_ID2});
    else
        cycleInput.mediumString = strcat(num2str(x_1*100), {' % '},...
            medium_vector_full(medium_ID1), {' / '}, num2str((1-x_1)*100), {' % '}, medium_vector_full(medium_ID2));
        simpleMediumString = strcat(num2str(x_1*100),...
            medium_vector_full{medium_ID1}, '_', num2str((1-x_1)*100), medium_vector_full{medium_ID2});
    end
    
    % Function Call
    try
        clear summary
        % Fluid was not yet simulated -> Run Simulation
        t_opt = tic;
        [COP, summary, cycle] = Opt_HP_std_cycle(boundaryCond, cycleInput, componentInput, solverInput, economyInput);
        toc(t_opt);
        
        summary_cell(iter_results, :) = {cycleInput.mediumString summary.Performance.COP summary.Performance.p_evap/100 summary.Performance.p_cond/100 ...
            summary.Investment.TCI_spec summary.Economy.NPV_total summary.Economy.PBT summary.Economy.c_hg};


    catch
        summary_cell(iter_results, :) = {cycleInput.mediumString NaN NaN NaN NaN NaN NaN NaN};        
    end
    
    
    
end

%% Save Results to Table
table_summary_results = cell2table(summary_cell, 'VariableNames', {'Medium', 'COP', 'p_evap', 'p_cond', 'TCI_spec', 'NPV', 'PBT', 'c_hg'})
save('CaseStudy_I/Results/table_summary_BestCasesAnalysis', 'table_summary_results');

%% -------------------------------------------------------------------- %%
%                        Plot Figures                                    %
% ---------------------------------------------------------------------  %  

