%% ------------------------------------------------------------------------
% The file is part of the numerical models: "Numerical models for the
% design and analysis of heat pumps with zeotropic mixtures". All
% information about copyright, licenses and authors can be found in the
% attached documentation.
% doi: 10.11583/DTU.6825443
% Copyright (c) 2018, B. Zhlsdorf, DTU <bezuhls@mek.dtu.dk>, 03/12/2018
% -------------------------------------------------------------------------

% --------------------------------------------------------------------- %%
%                          Load Inputs                                   %
% ---------------------------------------------------------------------  %   
load('CaseStudy_I/Inputs_CaseStudy_I.mat');

% Load list of fluids
ListOfFluids;

% --------------------------------------------------------------------- %%
%                        Define Medium                                   %
% ---------------------------------------------------------------------  %       
% Define Medium ID -> See list of defined media
    medium_ID1 = 6; % 6 => Propane
    medium_ID2 = 10; % 9 => Butane
  
    % Define composition between 0 ... 1
    x_1=0.8; 	
    x_2=1-x_1;
   
% Definition of medium string
    if x_1==1 
        medium = {medium_vector{medium_ID1}};
        composition = 1;
    elseif x_1==0
        medium = {medium_vector{medium_ID2}};
        composition = 1;
    else
        medium = {medium_vector{medium_ID1}, medium_vector{medium_ID2}};
        composition = [x_1; x_2];
    end
    
    cycleInput.medium = medium;
    cycleInput.composition = composition;
    
    if x_1==1
        cycleInput.mediumString = strcat(medium_vector_full(medium_ID1));
    else
        cycleInput.mediumString = strcat(num2str(x_1*100), {' % '},...
                    medium_vector_full(medium_ID1), {' / '}, num2str((1-x_1)*100), {' % '}, medium_vector_full(medium_ID2));
    end    
    
% Check Refprop Version
% display(strcat({'Refprop Version: '}, {num2str(refpropm_v1('0','c', 0,'',0, {'water'}, 1))}))  ; 

% --------------------------------------------------------------------- %%
%                    Define  Cycle Parameter                             %
% ---------------------------------------------------------------------  %   
    % Superheating
    SH_index=2;
    delta_T_minSH_vector = [0.05 5];
    cycleInput.delta_T_minSH = delta_T_minSH_vector(SH_index);

% Set Pressure drops for refrigerant flow in flow direction
    % Evaporator
    cycleInput.dp_evap  = 0*ones(componentInput.HX.n_states_evap-1,1);%  zeros(componentInput.HX.n_states_evap-1,1);
    % Superheater
    cycleInput.dp_sh    = 0*ones(componentInput.HX.n_states_sh-1,1);
    
    % Desuperheater
    cycleInput.dp_desup = 0*ones(componentInput.HX.n_states_desup-1,1);
    % Condenser
    cycleInput.dp_cond  = 0*ones(componentInput.HX.n_states_cond-1,1);   
    % Subcooler
    cycleInput.dp_sub   = 0*ones(componentInput.HX.n_states_sub-1,1);      

% Compressor
    % Constant isentropic compressor efficiency
    cycleInput.Define_Efficiency = 'constant';    % -> componentInput.Comp.eta_is_comp_design is used
    
    % Considering the built in pressure ratio
%     cycleInput.Define_Efficiency = 'BuiltInPressureRatio';    % If on, isentropic efficiency is calculated according to Granryd, considering the built in volume ratio
%     componentInput.Comp.pi_comp = 3;     % Built in volume ratio (can be estimated by PR^(1/kappa)

% --------------------------------------------------------------------- %%
%                  Define  Boundary Conditions                           %
% ---------------------------------------------------------------------  %   
    % Load
        % Define parameter to define the dimensioning of the cycle among: cycleInput.DefineLoad   = ...
        % - Supplied heat load:     'Q_dot_sink'        -> supply cycleInput.Q_dot_sink = 300000; (in [W]) 
        % - Supplied heat load:     'Q_dot_source'      -> supply cycleInput.Q_dot_source = 300000; (in [W]) 
%         % - Compressor inlet V_dot: 'V_dot_comp_in'     -> supply cycleInput.V_dot_comp_in = 0.01; (in [m3/s])
 
%     cycleInput.DefineLoad   = 'Q_dot_sink';     % Fixed supplied heat load
%     cycleInput.Q_dot_sink = 13900;              % [W]
    
%     cycleInput.DefineLoad   = 'Q_dot_source';  % Fixed supplied cooling load
%     cycleInput.Q_dot_source = 12331;             % [W]
%     
%     cycleInput.DefineLoad    = 'V_dot_comp_in';  % Fixed volume flow rate at compressor inlet
%     cycleInput.V_dot_comp_in = 300/3600;        % [m3/s]

%     cycleInput.DefineLoad    = 'V_dot_comp_disp';  % Fixed displacement rate at compressor inlet
%     cycleInput.V_dot_comp_disp = 300/3600;        % [m3/s]

    % Heat Exchanger
    % Define parameter to define the size of the heat exchangers and thereby the temperature differences and the evaporation & condensation pressure
    % Possible choices are:
    % - Min Pinch point temperatures:   'minPinch'          -> Supply minimum pinch point temperatures for source, sink and subcooling      
    % - Pinch point temperatures:       'Pinch'             -> Supply exact pinch point temperatures for source, sink and subcooling  
    % - UA Values:                      'UA'                -> Supply UA values for source and sink and a pinch to fix the subcooling
    % - Investment:                     'Invest'            -> Supply ourchased equipment cost for heat exchangers and the pinch to fix the subcooling    
    
% cycleInput.DefineHX     = 'minPinch';       % Design approach to set the minimum pinch point temperatures in all heat exchangers (Note: E.g. NPV optimization might yield a higher pinch temperature diff.)
% componentInput.HX.delta_T_pinch_source_min = 1;   % [K]
% componentInput.HX.delta_T_pinch_sink_min = 1;     % [K]
% componentInput.HX.delta_T_pinch_sub_min = 2;      % [K]

cycleInput.DefineHX     = 'Pinch';       % Design approach to set the exact pinch point temperatures in all heat exchangers (Note: E.g. NPV optimization might yield a higher pinch temperature diff.)
componentInput.HX.delta_T_pinch_source_min = 3;   % [K]
componentInput.HX.delta_T_pinch_sink_min = 3;     % [K]
componentInput.HX.delta_T_pinch_sub_min = 3;      % [K]

% cycleInput.DefineHX     = 'UA';             % Design approach to fix the UA value of source and sink HX and the pinch point for subcooling
% componentInput.HX.UA_source_total = 4.469851534862974e+04;          % [W/K]
% componentInput.HX.UA_sink_total = 6.039594702383247e+04;            % [W/K]
% componentInput.HX.delta_T_pinch_sub_min = 5;        % [K]
% componentInput.HX.delta_T_pinch_source_min = 5;     % [K]   <- Value is only used for defining the guess values!
% componentInput.HX.delta_T_pinch_sink_min = 5;       % [K]   <- Value is only used for defining the guess values!
% 
% cycleInput.DefineHX     = 'Invest';          % Design approach to fix the total Investment of source and sink HX and the pinch point for subcooling
% economyInput.HX.PEC_HX_total = 10000;               % [], Sum of purchased equipment cost for HX
% componentInput.HX.delta_T_pinch_sub_min = 5;        % [K]
% componentInput.HX.delta_T_pinch_source_min = 5;     % [K]   <- Value is only used for defining the guess values!
% componentInput.HX.delta_T_pinch_sink_min = 5;       % [K]   <- Value is only used for defining the guess values!
    
% Optimized Variable
   cycleInput.Objective    = 'COP';            % Optimization yields the highest obtainable coefficient of performance (COP) 
%     cycleInput.Objective    = 'NPV';            % Optimization yields the highest obtainable net present value (NPV)

                                                
% --------------------------------------------------------------------- %%
%                        Calculation Options                             %
% ---------------------------------------------------------------------  %      
    economyInput.calcInv    = 'on';     % Define if investment cost should be calculated -> can be replaced by 'off'
    economyInput.calcEco    = 'on';     % Define if economy should be calculated -> can be replaced by 'off'
        
    cycleInput.calcExergy   = 'on';     % Define if exergy analysis is conducted -> can be replaced by 'off'
%     boundaryCond.T_source_in = 273.15+40;           % [K]
% --------------------------------------------------------------------- %%
%                      Call Function/Optimization                        %
% ---------------------------------------------------------------------  %      
t_opt = tic;    
[COP, summary, cycle] = Opt_HP_std_cycle(boundaryCond, cycleInput, componentInput, solverInput, economyInput);
toc(t_opt);

display(strcat('Fluid: ', cycleInput.mediumString{1}))
display(strcat('COP = ', num2str(summary.Performance.COP) , ', -'))
display(strcat('TCI = ', num2str(summary.Investment.TCI/1e6) , 'Mio.'))
display(strcat('spec. Investment = ', num2str(summary.Investment.TCI/(summary.EB.Q_dot_sink)*1000) , '/kW'))
display(strcat('NPV = ', num2str(summary.Economy.NPV_total/1e6) , 'Mio.'))
display(strcat('PBT = ', num2str(summary.Economy.PBT) , 'years'))
display(strcat('c_HG = ', num2str(summary.Economy.c_hg) , '/MWh'))
% summary.TQ.delta_T_pinch_source


% --------------------------------------------------------------------- %%
%                        Plot Figures                                    %
% ---------------------------------------------------------------------  %  
% Plot TQ Diagram
    % Load default options for TQ plot
    load('Figures/options_TQ_default');
    % Adjust default options as required
    options_TQ.ylim = [10 100];
    options_TQ.XScale = 'relative';
    options_TQ.width = 8;          % Width of Figure in cm
    options_TQ.height = 7;         % Height of Figure in cm
    % options_TQ.grid = 'off';
    options_TQ.box = 'off';
    % Plot TQ
    Figure_TQ = Function_TQ_diagram_HP_std(summary, cycle, options_TQ);

% Plot log(p)-h_diagram
    % Load default options for log(p)-h-diagram
    load('Figures/options_logph_default');
    % Adjust default options as requiredk
    options_logph.width = 8;          % Width of Figure in cm
    options_logph.height = 7;         % Height of Figure in cm
    Function_logph_diagram(summary, cycle, options_logph);
