%% ------------------------------------------------------------------------
% The file is part of the numerical models: "Numerical models for the
% design and analysis of heat pumps with zeotropic mixtures". All
% information about copyright, licenses and authors can be found in the
% attached documentation.
% doi: 10.11583/DTU.6825443
% Copyright (c) 2018, B. Zhlsdorf, DTU <bezuhls@mek.dtu.dk>, 03/12/2018
% -------------------------------------------------------------------------

% This script summarizes the results in a summary file that can be used for
% plotting purposes

% Define folder path into which the results are saved
result_path = 'CaseStudy_I/Results/20180719/';

% Load List of fluids
ListOfFluids;

% Omit Water and Ammonia? -> Otherwise outcomment next line
n_media=18;

% Set running index to 1
iter_results = 1;

% Preallocate Space
summary_cell = cell(2000, 16);
Results = NaN(n_x, 9, n_media, n_media);

%% Summarize results
for medium_ID1=1:n_media
    for medium_ID2=(medium_ID1+1):n_media
        for i_x=1:n_x
            
            % Define Inputs for Model Evaluation
            x_1=x_1_vector(i_x);
            x_2=1-x_1;
 
            if x_1==1 
                medium = {medium_vector{medium_ID1}};
                composition = 1;
            elseif x_1==0
                medium = {medium_vector{medium_ID2}};
                composition = 1;
            else
                medium = {medium_vector{medium_ID1}, medium_vector{medium_ID2}};
                composition = [x_1; x_2];
            end            
            
            if x_1==1
                mediumString = strcat(medium_vector_full(medium_ID1));
                simpleMediumString = strcat(medium_vector_full{medium_ID1});
            elseif x_1==0
                mediumString = strcat(medium_vector_full(medium_ID2));
                simpleMediumString = strcat(medium_vector_full{medium_ID2});
            else
                mediumString = strcat(num2str(x_1*100), {' % '},...
                    medium_vector_full(medium_ID1), {' / '}, num2str((1-x_1)*100), {' % '}, medium_vector_full(medium_ID2));
                simpleMediumString = strcat(num2str(x_1*100),...
                    medium_vector_full{medium_ID1}, '_', num2str((1-x_1)*100), medium_vector_full{medium_ID2});
            end
            
            load(strcat(result_path, simpleMediumString, '.mat'));
            
            try
                if ~isreal([summary.Performance.COP summary.Economy.NPV_total summary.Economy.PBT summary.Economy.c_hg summary.Investment.TCI_spec])
                    % Result contains imaginary numbers
                    display(strcat(summary.mediumString{1},': Solution contained imaginary numbers'))
                    summary_cell(iter_results, :) = {iter_results simpleMediumString medium_vector_full{medium_ID1} medium_vector_full{medium_ID2} x_1 x_2 NaN NaN NaN NaN NaN NaN NaN NaN NaN NaN};
                    
                    Results( i_x, :, medium_ID1, medium_ID2) = [medium_ID1 medium_ID2 x_1 x_2 NaN NaN NaN NaN NaN];
                elseif summary.exitflag==(-2)
                    % No feasible solution was found
                    display(strcat(summary.mediumString{1},': No feasible solution was found'))
                    summary_cell(iter_results, :) = {iter_results simpleMediumString medium_vector_full{medium_ID1} medium_vector_full{medium_ID2} x_1 x_2 NaN NaN NaN NaN NaN NaN NaN NaN NaN NaN};
                    
                    Results( i_x, :, medium_ID1, medium_ID2) = [medium_ID1 medium_ID2 x_1 x_2 NaN NaN NaN NaN NaN];
                else
                    % All other feasible solutions
                    summary_cell(iter_results, :) = {iter_results simpleMediumString medium_vector_full{medium_ID1} medium_vector_full{medium_ID2} x_1 x_2 summary.Performance.COP ...
                        summary.Economy.NPV_total summary.Economy.PBT summary.Economy.c_hg summary.Investment.TCI_spec, ...
                        summary.Performance.p_evap/100 summary.Performance.p_cond/100 summary.Performance.p_evap/summary.Performance.p_cond,...
                        summary.Performance.VHC/1000 summary.exitflag};
                    
                    Results( i_x, :, medium_ID1, medium_ID2) = [medium_ID1 medium_ID2 x_1 x_2 ...
                           summary.Performance.COP summary.Economy.NPV_total summary.Economy.PBT summary.Economy.c_hg summary.Investment.TCI_spec];

                end
            catch
                summary_cell(iter_results, :) = {iter_results simpleMediumString medium_vector_full{medium_ID1} medium_vector_full{medium_ID2} x_1 x_2 NaN NaN NaN NaN NaN NaN NaN NaN NaN NaN};
            end
            iter_results = iter_results+1;
         end
    end
end

%% Save Results structure
save(strcat('CaseStudy_I/Results/Results_complete_CaseI','.mat'), 'Results');

%% Save Results to Table
table_summary_results = cell2table(summary_cell, 'VariableNames', ...
    {'Index', 'Medium', 'Medium1', 'Medium2', 'x_1', 'x_2', 'COP', 'NPV', 'PBT', 'c_hg', 'TCI_spec', 'p_evap', 'p_cond', 'p_ratio', 'VHC', 'exitflag'});
save('CaseStudy_I/Results/table_summary_allResults', 'table_summary_results');

% Save Results to Excel table
variable_names = {'Index', 'MediumString', 'Medium 1', 'Medium 2', 'x_1', 'x_2', 'COP', 'NPV, ', 'PBT, years', 'c_hg, /MWh', 'TCI_spec, /kW',...
    'p_evap, bar', 'p_cond, bar', 'p_cond/p_evap, -', 'VHC, kJ/m3', 'exitflag'};

% Write empty files into excel sheet to avoid old values remaining in the file
xlswrite('CaseStudy_I/Results/CaseStudyI_allResults.xlsx', cell(2000, 16), 'Sheet1', 'A2');

writetable(table_summary_results, 'CaseStudy_I/Results/CaseStudyI_allResults.xlsx')
% Update first row incl. units
xlswrite('CaseStudy_I/Results/CaseStudyI_allResults.xlsx', variable_names, 'Sheet1', 'A1');