%% ------------------------------------------------------------------------
% The file is part of the numerical models: "Numerical models for the
% design and analysis of heat pumps with zeotropic mixtures". All
% information about copyright, licenses and authors can be found in the
% attached documentation.
% doi: 10.11583/DTU.6825443
% Copyright (c) 2018, B. Zhlsdorf, DTU <bezuhls@mek.dtu.dk>, 03/12/2018
% -------------------------------------------------------------------------

% Plot COP
% Define the indices of the relevant results in the structure
x_axes_index = 4;   % Definition of variable for x-axes: Composition of component 2
y_axes_index = 8;   % Definition of variable for y-axes: COP

% If Legend should be generated, figure size has to be adjusted and show_legend=true
show_legend=false;

%% --------------------------------------------------------------------------
% Load Results
load('Results_complete_CaseI');    

n_media = 18;

%% Define best solutions -> selecting 12 solutions is recommended
show_case =  [ 4  7
               5  9
               5 10
               5 17
               6 10
               6 18
               7 10
               7 11
               9 13
              11 16 
              13 17
              13 18
                   ];   

% Color Vector
% Generate vector of distinguishable colors
color_vector_generated = distinguishable_colors(12, 'w');

% Rearrange color order
color_vector = color_vector_generated;
color_vector(2,:) = color_vector_generated(4,:);
color_vector(4,:) = color_vector_generated(2,:);

% Generate vector of line styles
LS_vector = {'-'; '--'; '-.'};
          
%% --------------------------------------------------------------------- %%
%                          Plot Diagram                                   %
%  ---------------------------------------------------------------------  %    
    
% Figure inputs
fontsize = 10;
font = 'Times New Roman';

figure_width = 7.5;     % cm
figure_height = 5.5;    % cm

% Figure
figure_COP_x2 = figure('Units','Centimeters', 'Name', 'c_{hg} over x_2 for all mixtures',...
    'Position', [40 10 figure_width figure_height], ...
    'PaperSize', [figure_width figure_height], ...
    'PaperPosition', [40 10 figure_width figure_height]); % , 'ylim', [0 50], 'xlim', [0 1]

axes1 = axes('Parent', figure_COP_x2, ...
     'FontName', font, 'FontSize', fontsize, 'ylim', [24 36], 'xlim', [0 1],...
     'xTick', [0 0.2 0.4 0.6 0.8 1]); % , 'ylim', [0 50]
     hold on;
     box on;
     grid on;

color_index = 1;
legend_index=1;         

% Plot selected fluids to first generate legend entries
for medium_ID1=1:n_media
    for medium_ID2=medium_ID1+1:n_media
        if ismember([medium_ID1 medium_ID2],show_case, 'rows')
            % Plot selected solutions
            plot(Results(:, x_axes_index, medium_ID1, medium_ID2), Results(: ,y_axes_index , medium_ID1, medium_ID2), 'Color', color_vector(color_index,:), 'LineStyle', LS_vector{mod(color_index-1, length(LS_vector))+1})
            color_index = color_index+1;
            % Build Legend Vector
            if show_legend==true
                Legend(legend_index) = (strcat(medium_vector_full(medium_ID1),'/',medium_vector_full(medium_ID2)));
                legend_index=legend_index+1; 
            end
        end
    end
end

% Plot remaining fluids
for medium_ID1=1:n_media
    for medium_ID2=medium_ID1+1:n_media
    % Plot Vapor Dome     
        if ~ismember([medium_ID1 medium_ID2],show_case, 'rows')
            plot(Results(:, x_axes_index, medium_ID1, medium_ID2), Results(: ,y_axes_index , medium_ID1, medium_ID2),'Color', [0.8, 0.8, 0.8])
        end
 
    end
end

% Re-plot selected fluids to have them on top
color_index = 1;
for medium_ID1=1:n_media
    for medium_ID2=medium_ID1+1:n_media
    % Plot Vapor Dome     
        if ismember([medium_ID1 medium_ID2],show_case, 'rows')
            plot(Results(:, x_axes_index, medium_ID1, medium_ID2), Results(: ,y_axes_index , medium_ID1, medium_ID2), 'Color', color_vector(color_index,:), 'LineStyle', LS_vector{mod(color_index-1, length(LS_vector))+1})
            color_index = color_index+1;
        end
    end
end

ylabel('\itc_{\rmhg}\rm, /MWh','Rotation',90, 'FontName', font, 'FontSize', fontsize);
xlabel('Composition of Component 2, kg/kg', 'FontName',  font, 'FontSize', fontsize);   

if show_legend==true
    legend(Legend, 'Location', 'NorthOutside', 'Orientation', 'Vertical', 'FontName',  font, 'FontSize', fontsize, 'NumColumns', 4);
end
%% -----------------------------------------------------------------------
% Save Graphic    

% saveas(figure_COP_x2, 'Figures_Paper4DH/COP_x2_SH0K_Legend_etais50','emf');

