function [figure_TQ] = Function_TQ_diagram_HP_std(summary, cycle, options)

%% ------------------------------------------------------------------------
% The file is part of the numerical models: "Numerical models for the
% design and analysis of heat pumps with zeotropic mixtures". All
% information about copyright, licenses and authors can be found in the
% attached documentation.
% doi: 10.11583/DTU.6825443
% Copyright (c) 2018, B. Zhlsdorf, DTU <bezuhls@mek.dtu.dk>, 03/12/2018
% -------------------------------------------------------------------------

% Plot T-Q_dot-Diagram
% Get variables from summary result structures
COP = summary.Performance.COP;
p_evap = summary.Performance.p_evap;
p_cond = summary.Performance.p_cond;
Q_dot_sink = summary.EB.Q_dot_sink;


if strcmp(options.XScale, 'relative')==1
    Q_dot_sink_cum      = (Q_dot_sink-summary.TQ.Q_dot_sink_cum)/Q_dot_sink;
    Q_dot_source_cum    = summary.TQ.Q_dot_source_cum/Q_dot_sink;
    Q_dot_ihx_cum       = (summary.EB.Q_dot_source + summary.TQ.Q_dot_ihx_cum)/Q_dot_sink;  
    Q_dot_source        = summary.EB.Q_dot_source/Q_dot_sink;
    Q_dot_ihx           = summary.EB.Q_dot_ihx/Q_dot_sink;    
else
    Q_dot_sink_cum      = Q_dot_sink-summary.TQ.Q_dot_sink_cum;
    Q_dot_source_cum    = summary.TQ.Q_dot_source_cum;
    Q_dot_ihx_cum       = summary.EB.Q_dot_source + summary.TQ.Q_dot_ihx_cum;  
    Q_dot_source        = summary.EB.Q_dot_source;
    Q_dot_ihx           = summary.EB.Q_dot_ihx;
end

% Q_dot_sink_cum = Q_dot_sink-summary.TQ.Q_dot_sink_cum;
% Q_dot_source_cum = summary.TQ.Q_dot_source_cum;
T_sink      = summary.TQ.T_sink;
T_source    = summary.TQ.T_source;
T_evap      = summary.TQ.T_evap;
T_cond      = summary.TQ.T_cond;
T_ihx_hot 	= summary.TQ.T_ihx_hot; 
T_ihx_cold	= summary.TQ.T_ihx_cold; 

% Define options
width   = options.width ;                  % cm
height  = options.height;                  % cm
font    = options.font;
fs      = options.fs;

figure_TQ = figure('Units','Centimeters', 'Name', 'Temperature Heat Diagram',...
                   'Units','Centimeters', 'Position', [5 5 width height], ...
                   'PaperSize', [width height], ...
                   'PaperPosition', [0 0 width height]);

              
axes1 = axes('Parent', figure_TQ, ...
     'FontName', font, 'FontSize', fs); % , 'xlim', [0 1]
     hold on;
     
if strcmp(options.box, 'on')==1
    box on;
end
if strcmp(options.grid, 'on')==1
    grid on;
end

if strcmp(options.XScale, 'relative')==1
    xticks([0 0.2 0.4 0.6 0.8 1]);
    xticklabels({'0','20','40','60','80','100'});
end
     
if ~strcmp(options.ylim, 'auto')==1
    ylim(options.ylim)
end     

if ~strcmp(options.xlim, 'auto')==1
    xlim(options.xlim)
end     
     
plot(Q_dot_sink_cum, T_cond-273.15, '-g',...
     Q_dot_sink_cum, T_sink-273.15, '-r',...
     Q_dot_source_cum, T_source-273.15, '-b',...
     Q_dot_source_cum, T_evap-273.15, '-g',...
     fliplr(Q_dot_ihx_cum), fliplr(T_ihx_hot)-273.15, '-g',...
     Q_dot_ihx_cum, T_ihx_cold-273.15, '-g',...
     [0 Q_dot_source+abs(Q_dot_ihx)], [T_ihx_hot(1) T_ihx_hot(1)]-273.15, ':g');

% Title 
    Title = title([cycle.mediumString,...
               strcat({'COP = '}, num2str(COP, 3),...
               {', p_{evap} = '}, num2str(p_evap/100, 3),{' bar'},...
               {', p_{cond} = '}, num2str(p_cond/100, 3),{' bar'})]);

set(Title, 'FontName', font, 'FontSize', fs, 'FontWeight', 'Normal');

% Axes description
ylabel('Temperature, C','Rotation',90, 'FontName', font, 'FontSize', fs);
if strcmp(options.XScale, 'relative')==1
    xlabel('Transferred Energy per Heat Supply, %', 'FontName', font, 'FontSize', fs); 
else
    xlabel('Transferred Energy, W', 'FontName', font, 'FontSize', fs);     
end


% Plot arrows indicating the flow direction   
if mod(length(Q_dot_sink_cum),2)==0
    i_arrow_sink = [length(Q_dot_sink_cum)/2+1 length(Q_dot_sink_cum)/2];
else
    i_arrow_sink = [(length(Q_dot_sink_cum)-1)/2+1 (length(Q_dot_sink_cum-1)-1)/2];
end

if mod(length(Q_dot_source_cum),2)==0
    i_arrow_source = [length(Q_dot_source_cum)/2 length(Q_dot_source_cum)/2+1];
else
    i_arrow_source = [(length(Q_dot_source_cum)-1)/2 (length(Q_dot_source_cum)-1)/2+1];
end

if mod(length(Q_dot_ihx_cum),2)==0
    i_arrow_ihx = [length(Q_dot_ihx_cum)/2 length(Q_dot_ihx_cum)/2+2];
else
    i_arrow_ihx = [(length(Q_dot_ihx_cum)-1)/2 (length(Q_dot_ihx_cum)-1)/2+2];
end

% Length of arrow
l_arrow = 12;
Q_dot_ihx_cum_lr = fliplr(Q_dot_ihx_cum);

arrow([Q_dot_sink_cum(i_arrow_sink(2)), T_cond(i_arrow_sink(2))-273.15], [Q_dot_sink_cum(i_arrow_sink(1)), T_cond(i_arrow_sink(1))-273.15],...
    'Color', 'g', 'Length', l_arrow, 'Baseangle', 45);
arrow([Q_dot_sink_cum(i_arrow_sink(1)), T_sink(i_arrow_sink(1))-273.15], [Q_dot_sink_cum(i_arrow_sink(2)), T_sink(i_arrow_sink(2))-273.15],...
    'Color', 'r', 'Length', l_arrow, 'Baseangle', 45);
arrow([Q_dot_source_cum(i_arrow_source(2)), T_source(i_arrow_source(2))-273.15], [Q_dot_source_cum(i_arrow_source(1)), T_source(i_arrow_source(1))-273.15],...
    'Color', 'b', 'Length', l_arrow, 'Baseangle', 45);
arrow([Q_dot_source_cum(i_arrow_source(1)), T_evap(i_arrow_source(1))-273.15], [Q_dot_source_cum(i_arrow_source(2)), T_evap(i_arrow_source(2))-273.15],...
    'Color', 'g', 'Length', l_arrow, 'Baseangle', 45)
arrow([Q_dot_ihx_cum(i_arrow_ihx(1)), T_ihx_cold(i_arrow_ihx(1))-273.15], [Q_dot_ihx_cum(i_arrow_ihx(2)), T_ihx_cold(i_arrow_ihx(2))-273.15],...
    'Color', 'g', 'Length', l_arrow*0.8, 'Baseangle', 45)
arrow([Q_dot_ihx_cum_lr(i_arrow_ihx(1)), T_ihx_hot(i_arrow_ihx(1))-273.15], [Q_dot_ihx_cum_lr(i_arrow_ihx(2)), T_ihx_hot(i_arrow_ihx(2))-273.15],...
    'Color', 'g', 'Length', l_arrow*0.7, 'Baseangle', 45)

end