function [COP_max, summary, cycle] = Opt_HP_ihx_cycle(boundaryCond, cycleInput, componentInput, solverInput, economyInput);
%% ------------------------------------------------------------------------
% The file is part of the numerical models: "Numerical models for the
% design and analysis of heat pumps with zeotropic mixtures". All
% information about copyright, licenses and authors can be found in the
% attached documentation.
% doi: 10.11583/DTU.6825443
% Copyright (c) 2018, B. Zhlsdorf, DTU <bezuhls@mek.dtu.dk>, 03/12/2018
%% ------------------------------------------------------------------------

% Declare variables by inputs
medium      = cycleInput.medium;
composition = cycleInput.composition;

% Boundary conditions for direct use
% Heat Source
T_source_in = boundaryCond.T_source_in;     
T_source_out = boundaryCond.T_source_out;    

% Heat Sink
T_sink_in = boundaryCond.T_sink_in;
T_sink_out = boundaryCond.T_sink_out;  

% --------------------------------------------------------------------- %%
%                  Define Bounds and Guess values                        %
% ---------------------------------------------------------------------  %     
% Critical Properties 
% Call SATSPLN
    Run_SATSPLN=1;    % if = 1, SATSPLN is called
    save('C:\Program Files\REFPROP\Run_SATSPLN', 'Run_SATSPLN');
    [T_crit, p_crit, ~, ~]  = refpropm_v1('Tphs', 'c', 0,'',0, medium, composition);
    Run_SATSPLN=0;
    save('C:\Program Files\REFPROP\Run_SATSPLN', 'Run_SATSPLN');

% Lower and upper bounds 
    try
        p_min_L         = refpropm_v1('p', 'r', 0,'',0, medium, composition)*1.01;%0.0000001;
    catch
        p_min_L         = 1;
    end
    try
        p_max_L         = refpropm_v1('p', 'T', T_source_in + componentInput.HX.delta_T_pinch_source_min, 'Q', 1, medium, composition); %50;T_source_in - delta_T_pinch_source_min
                                          % T_source_in - delta_T_pinch_source_min
    catch
        p_max_L         = p_crit;
    end
    if refpropm_v1('p', 'T', T_sink_in , 'Q', 0, medium, composition)<=0.9*p_crit
        p_min_H     = refpropm_v1('p', 'T', T_sink_in , 'Q', 0, medium, composition); %;50
    else
        p_min_H     = 0.3*p_crit;% p_min_L;
    end
    p_max_H         = 3* refpropm_v1('p', 'c', 0,'',0, medium, composition);    % T_sink_in  + delta_T_pinch_sink_min

    lb = [p_min_L p_min_H];
    ub = [p_max_L p_max_H];
    
% Start values
% Evaporation Pressure
    x0(1) = refpropm_v1('p', 'T', T_source_out-componentInput.HX.delta_T_pinch_source_min, 'Q', 1, medium, composition); % Evaporation Pressure
    % Condensation Pressure

    if (T_sink_in+componentInput.HX.delta_T_pinch_sink_min)<= solverInput.limit_sc*T_crit
        % Subcritical guess value
        try
            x0(2) = refpropm_v1('p', 'T', T_sink_out+componentInput.HX.delta_T_pinch_sink_min, 'Q', 1, medium, composition);
        catch
            x0(2) = p_min_L * 1.1;
        end
    else
        % Transcritical guess value
        x0(2) = p_crit * 1.2;
    end

x_iter      = [];
save HPOptimizationCalls/iteration.mat x_iter;

% Options
economyInput_opt            = economyInput;
if strcmp(cycleInput.Objective, 'NPV')==1
    economyInput_opt.calcInv    = 'on';      % Define if investment cost should be calculated -> can be replaced by 'off'
    economyInput_opt.calcEco    = 'on';      % Define if economy should be calculated -> can be replaced by 'off'
else
    economyInput_opt.calcInv    = 'off';      % Define if investment cost should be calculated -> can be replaced by 'off'
    economyInput_opt.calcEco    = 'off';      % Define if economy should be calculated -> can be replaced by 'off'
end

cycleInput_opt              = cycleInput;
cycleInput_opt.calcExergy   = 'off';

% --------------------------------------------------------------------- %%
%                      Call Function/Optimization                        %
% ---------------------------------------------------------------------  %  
%  Definition of anonymous function, which has only x as input
fun_HP_all = @(x)HP_ihx_cycle(x, boundaryCond, cycleInput, componentInput, solverInput, economyInput_opt);

% Declaration of variables in nested functions
xLast = []; % Last place computeall was called
myf = []; % Use for objective at xLast
myc = []; % Use for nonlinear inequality constraint
myceq = []; % Use for nonlinear equality constraint

% Definition of options for the optimizer
options = optimoptions('fmincon');
options = optimoptions(options,'MaxFunctionEvaluations', 500);
if strcmp(cycleInput.Objective, 'NPV')==1
    options = optimoptions(options,'StepTolerance', 1e-4);
end
% options = optimoptions(options,'ConstraintTolerance', 1e-6);
% options = optimoptions(options,'PlotFcn', { @optimplotx });
% options = optimoptions(options,'PlotFcn', {@optimplotx @optimplotstepsize });
% options = optimoptions(options,'OutputFcn', { @outfun });
% options = optimoptions(options,'Display','iter-detailed');
% options = optimoptions(options,'Display','final-detailed');
options = optimoptions(options,'MaxIterations', 100);
% options = optimoptions(options,'Diagnostics', 'on');
% Call Optimization
[x, ~, exitflag,~,~,~,~] = fmincon(@objfun,x0,[],[],[],[],lb,ub, @constr, options);%,constraint

% Re-evaluate Cycle model to get all values
[COP_max, summary, cycle] = HP_ihx_cycle(x, boundaryCond, cycleInput, componentInput, solverInput, economyInput);

summary.exitflag = exitflag;

% --------------------------------------------------------------------- %%
%                        Nested Functions                                %
% ---------------------------------------------------------------------  %  
% Since our function provides both objective and constraints in the same function, while
%      fmincon assumes that these are normally supplied by independent functions,
%      it is required to use the nested functions for avoiding calling the
%      function twice
% See for further information: https://de.mathworks.com/help/optim/ug/objective-and-nonlinear-constraints-in-the-same-function.html
 
    function y = objfun(x)
        if ~isequal(x,xLast) % Check if computation is necessary
            [myCOP, mysummary, ~] = fun_HP_all(x);
            
            % Define Optimized Variable
            switch cycleInput.Objective
                case 'COP'
                    myf = - myCOP; % -mysummary.Economy.NPV; %
                case 'NPV'
                    myf = - mysummary.Economy.NPV_total;
                otherwise
                    error('Defined objective function is not implemented')
            end
            
            % Define Boundary Conditions
            switch cycleInput.DefineHX
                case 'minPinch'
                    % Define inequality constraints, so that c(x)<=0
                    myc = [componentInput.HX.delta_T_pinch_source_min - mysummary.TQ.delta_T_pinch_source ...
                    componentInput.HX.delta_T_pinch_sink_min - mysummary.TQ.delta_T_pinch_sink];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [];                
                case 'Pinch'
                    % Define inequality constraints, so that c(x)<=0
                    myc = [];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [componentInput.HX.delta_T_pinch_source_min - mysummary.TQ.delta_T_pinch_source ...
                    componentInput.HX.delta_T_pinch_sink_min - mysummary.TQ.delta_T_pinch_sink];
                case 'UA'
                    % Define inequality constraints, so that c(x)<=0
                    myc = [];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [componentInput.HX.UA_source_total - mysummary.Component.HX.UA_source_total ...
                    componentInput.HX.UA_sink_total - mysummary.Component.HX.UA_sink_total];
                case 'Invest'
                    % Define inequality constraints, so that c(x)<=0
                    myc = [];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [economyInput.HX.PEC_HX_total - mysummary.Investment.PEC_Evap - mysummary.Investment.PEC_Cond];                
                otherwise
                    error('Defined boundary conditions are not implemented')
            end
            
            xLast = x;
        end
        % Now compute objective function
        y = myf;
    end

    function [c,ceq] = constr(x)
        if ~isequal(x,xLast) % Check if computation is necessary
            [myCOP, mysummary, ~] = fun_HP_all(x);
            
            % Define Optimized Variable
            switch cycleInput.Objective
                case 'COP'
                    myf = - myCOP; % -mysummary.Economy.NPV; %
                case 'NPV'
                    myf = - mysummary.Economy.NPV_total;
                otherwise
                    error('Defined objective function is not implemented')
            end
            
            % Define Boundary Conditions
            switch cycleInput.DefineHX
                case 'minPinch'
                    % Define inequality constraints, so that c(x)<=0
                    myc = [componentInput.HX.delta_T_pinch_source_min - mysummary.TQ.delta_T_pinch_source ...
                    componentInput.HX.delta_T_pinch_sink_min - mysummary.TQ.delta_T_pinch_sink];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [];  
                case 'Pinch'
                    % Define inequality constraints, so that c(x)<=0
                    %             myc = [mysummary.TQ.delta_T_pinch_source mysummary.TQ.delta_T_pinch_source]
                    myc = [];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [componentInput.HX.delta_T_pinch_source_min - mysummary.TQ.delta_T_pinch_source ...
                    componentInput.HX.delta_T_pinch_sink_min - mysummary.TQ.delta_T_pinch_sink];
                case 'UA'
                    % Define inequality constraints, so that c(x)<=0
                    myc = [];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [componentInput.HX.UA_source_total - mysummary.Component.HX.UA_source_total ...
                    componentInput.HX.UA_sink_total - mysummary.Component.HX.UA_sink_total];
                case 'Invest'
                    % Define inequality constraints, so that c(x)<=0
                    myc = [];
                    % Define equality constraints, so that ceq(x)=0
                    myceq = [economyInput.HX.PEC_HX_total - mysummary.Investment.PEC_Evap - mysummary.Investment.PEC_Cond];                  
                otherwise
                    error('Defined boundary conditions are not implemented')
            end
            
            xLast = x;
        end
        % Now compute constraint functions
        c = myc; % In this case, the computation is trivial
        ceq = myceq;
    end
        
    % Output function for saving the iteration variables
    function stop = outfun(x,optimValues,state)
        stop = false;
        
        load Optimization_HP_cycle/iteration.mat x_iter;
        x_iter(optimValues.iteration+1,:) = x;
        save Optimization_HP_cycle/iteration.mat x_iter;
    end

end
