%% ------------------------------------------------------------------------
% The file is part of the numerical models: "Numerical models for the
% design and analysis of heat pumps with zeotropic mixtures". All
% information about copyright, licenses and authors can be found in the
% attached documentation.
% doi: 10.11583/DTU.6825443
% Copyright (c) 2018, B. Zhlsdorf, DTU <bezuhls@mek.dtu.dk>, 03/12/2018
% -------------------------------------------------------------------------

%% Test of interfaces for medium property calls
% This scripts tests if the interfaces for calling the medium properties
% are placed correctly. The user should be able to run this script before
% using the numerical models.

addpath(genpath('C:\Program Files\REFPROP'));   % This is where the refpropm.m should be placed according to Refprop
addpath(genpath('C:\Program Files\Coolprop'));  % Here are the functions for Coolprop placed

%% REFPROP (used for the medium properties of the mixtures)
% Calling the critical properties of a mixture:
    medium = {'propane', 'butane'};
    composition = [0.3; 0.7];

% Critical Properties 
% Call SATSPLN (SATSPLN interploates the medium properties close to the
%   critical point and improves the convergence -> See documentation for
%   furthre information)
    Run_SATSPLN=1;    % if = 1, SATSPLN is called
    save('C:\Program Files\REFPROP\Run_SATSPLN', 'Run_SATSPLN');
    [T_crit, p_crit, ~, ~]  = refpropm_v1('Tphs', 'c', 0,'',0, medium, composition);
    Run_SATSPLN=0;
    save('C:\Program Files\REFPROP\Run_SATSPLN', 'Run_SATSPLN');
 
% Display results    
mediumString = strcat(num2str(composition(1,1)*100), {' % '},...
                    medium(1), {' / '}, num2str((1-composition(1,1))*100), {' % '}, medium(2));
display(strcat('Fluid: ', mediumString{1}))
display(strcat('p_crit = ', num2str(p_crit/100, 4) , ', bar'))
display(strcat('T_crit = ', num2str(T_crit-273.15, 4) , ' C'))

%% Coolprop (used for the medium properties of the heat source and sink)

T_sat       = CoolProp.PropsSI('T', 'Q', 1, 'P', 1e5,  'water');

display(strcat('Boiling point of water at 1 bar: ', num2str(T_sat-273.15,4), ' C'))

